Track
=================

.. autoclass:: shephard.track.Track


Track Properties
................
.. autofunction:: shephard.track.Track.name
.. autofunction:: shephard.track.Track.values
.. autofunction:: shephard.track.Track.symbols
.. autofunction:: shephard.track.Track.protein
.. autofunction:: shephard.track.Track.track_type

Track Functions
...............
.. autofunction:: shephard.track.Track.symbol
.. autofunction:: shephard.track.Track.value
.. autofunction:: shephard.track.Track.symbols_region
.. autofunction:: shephard.track.Track.values_region


Track Attribute Functions
...........................
.. autofunction:: shephard.track.Track.attributes
.. autofunction:: shephard.track.Track.attribute
.. autofunction:: shephard.track.Track.add_attribute
.. autofunction:: shephard.track.Track.remove_attribute


